import java.io.IOException;
import java.util.Iterator;

import org.apache.jena.atlas.logging.Log;

import com.hp.hpl.jena.rdf.model.InfModel;
import com.hp.hpl.jena.rdf.model.Model;
import com.hp.hpl.jena.rdf.model.ModelFactory;
import com.hp.hpl.jena.reasoner.Reasoner;
import com.hp.hpl.jena.reasoner.ReasonerRegistry;
import com.hp.hpl.jena.reasoner.ValidityReport;
import com.hp.hpl.jena.reasoner.ValidityReport.Report;

public class InferAll {
	
	 static { Log.setCmdLogging() ; }
	 
	public static void main(String args[]) throws IOException {
		ModelLoader loader = new ModelLoader();
		boolean useRDFSReasoner = false;
		
		/* Bad parameter (i.e. no data file) */
		if (args.length == 0) {
			System.out.println("usage: java -jar infertool.jar [--rdfs] [--owlfull] data-files\n" +
					"\t By default --owlfull is assumed meaning that inference will be done using JENA's OWL reasoner (which is incomplete!)\n"+
					"\t If --rdfs is specified, then reasoning will only be done on subproperty, subclass, domain and range (no axiomatic triples)\n" +
					"\t data-files is a list of white-space sperated filenames from which the inference should be drawn."
					);
			return;
		}
		
		/* Load the data */
		for (String arg: args) {
			if ( arg.equals("--rdfs") ) {
				useRDFSReasoner = true;
				continue;
			}
			if  ( arg.equals("--owlfull") ) 
				continue;
			
			loader.loadData(arg);
		}
		
		/* Dump the data */
		Model m = loader.getModel();
		Reasoner r = null;
		if ( useRDFSReasoner )
			r = ReasonerRegistry.getRDFSSimpleReasoner();
		else
			r = ReasonerRegistry.getOWLReasoner();

		InfModel i = ModelFactory.createInfModel(r, m);
		
		ValidityReport reports = i.validate();
		if (reports.isValid()) {
			i.write(System.out, ModelLoader.DataFormats.turtle.lang);
		}
		else {
			System.out.println("The file contain the following inconsistencies: ");
			for (Iterator<Report> it = reports.getReports(); it.hasNext(); ) {
	            System.out.println(" - " + it.next());							
			}
		}
	}
}
