import java.io.File;
import java.util.HashMap;

import com.hp.hpl.jena.rdf.model.Model;
import com.hp.hpl.jena.rdf.model.ModelFactory;

public class ModelLoader {

	/**
	 * The dataformats that we support
	 *
	 */
	public static enum DataFormats {
		rdfxml ("RDF/XML"),
		ntriples ("N-TRIPLE"),
		turtle ("TURTLE"),
		n3 ("N3");

		public String lang;
		private DataFormats(String lang) {
			this.lang = lang;
		}
	}

	/* A mapping from file extensions to the corresponding format */
	private static final HashMap<String, DataFormats> extensions;
	static
	{
		extensions = new HashMap<String, DataFormats>();
		extensions.put("ttl", DataFormats.turtle);
		extensions.put("rdf", DataFormats.rdfxml);
		extensions.put("nt", DataFormats.ntriples);
		extensions.put("n3", DataFormats.n3);
	}

	private Model model;
	
	public Model getModel() {
		return model;
	}

	public ModelLoader(){
		this(ModelFactory.createDefaultModel());
	}
	
	public ModelLoader(Model model){
		this.model = model;
	}

	/***
	 * Given a filename, guess the format of the file based on the file extension, and parse the file accordingly, adding all of its information 
	 * to the model.
	 * @param rdfFile
	 */
	public void loadData(String rdfFile) {
		DataFormats lang = DataFormats.rdfxml;

		if (rdfFile.lastIndexOf('.') != -1) {
			String ext = rdfFile.substring(rdfFile.lastIndexOf('.') + 1);

			if (extensions.containsKey(ext)) {
				lang = extensions.get(ext);
			}
		}
		loadData(rdfFile, lang);
	}

	/**
	 * Given a filename and a format, parese the contents on the file according to the format. Add all of the information in the file to the model.
	 * @param rdfFile
	 * @param format
	 */
	public void loadData(String rdfFile, DataFormats format) {
		model.read((new File(rdfFile)).toURI().toString(), format.lang);
	}
}
